% Isotope Model

%     1-dimensional model of water vapor transport based on
%     Hendricks, M. B., . J. DePaolo, and R. C. Cohen.  2000.
%     "Space and time variation of 'del 18 O' and 'del D' in 
%     precipitation: Can paleotemperature be estimated from ice 
%     cores?"  Global Biogeochemical Cycles, 14(3), 851-861.
%
%     This version is in Cartesian coordinates and has been developed
%     to calculate the isotopic composition of precipitation in 
%     the Andes

% Read in parameter values

isotope_model_values_Andes

% Calculate d_tc/d_l:

denom1=24*l_incr;

i=1;

d_tc(i,1)=l(i);
d_tc(i,2)=(-50*tc(i,2)+96*tc(i+1,2)-72*tc(i+2,2) ...
 +32*tc(i+3,2)-6*tc(i+4,2))/denom1;

i=2;

d_tc(i,1)=l(i);
d_tc(i,2)=(-6*tc(i-1,2)-20*tc(i,2)+36*tc(i+1,2) ...
 -12*tc(i+2,2)+2*tc(i+3,2))/denom1;

for i=3:1:(number_nodes-2)

  d_tc(i,1)=l(i);
  d_tc(i,2)=(2*tc(i-2,2)-16*tc(i-1,2)+16*tc(i+1,2) ...
   -2*tc(i+2,2))/denom1;

end

i=(number_nodes-1);

d_tc(i,1)=l(i);
d_tc(i,2)=(-2*tc(i-3,2)+12*tc(i-2,2)-36*tc(i-1,2) ...
 +20*tc(i,2)+6*tc(i+1,2))/denom1;

i=number_nodes;

d_tc(i,1)=l(i);
d_tc(i,2)=(6*tc(i-4,2)-32*tc(i-3,2)+72*tc(i-2,2) ...
 -96*tc(i-1,2)+50*tc(i,2))/denom1;

% Calculate d_wc/d_l, d2_wc/d_l2:

denom1=24*l_incr;
denom2=12*(l_incr^2);

i=1;

d_wc(i,1)=l(i);
d_wc(i,2)=(-50*wc(i,2)+96*wc(i+1,2)-72*wc(i+2,2) ...
 +32*wc(i+3,2)-6*wc(i+4,2))/denom1;

d2_wc(i,1)=l(i);
d2_wc(i,2)=(35*wc(i,2)-104*wc(i+1,2)+114*wc(i+2,2) ...
 -56*wc(i+3,2)+11*wc(i+4,2))/denom2;

i=2;

d_wc(i,1)=l(i);
d_wc(i,2)=(-6*wc(i-1,2)-20*wc(i,2)+36*wc(i+1,2) ...
 -12*wc(i+2,2)+2*wc(i+3,2))/denom1;

d2_wc(i,1)=l(i);
d2_wc(i,2)=(11*wc(i-1,2)-20*wc(i,2)+6*wc(i+1,2) ...
 +4*wc(i+2,2)-1*wc(i+3,2))/denom2;

for i=3:1:(number_nodes-2)

  d_wc(i,1)=l(i);
  d_wc(i,2)=(2*wc(i-2,2)-16*wc(i-1,2)+16*wc(i+1,2) ...
   -2*wc(i+2,2))/denom1;

  d2_wc(i,1)=l(i);
  d2_wc(i,2)=(-1*wc(i-2,2)+16*wc(i-1,2)-30*wc(i,2) ...
   +16*wc(i+1,2)-1*wc(i+2,2))/denom2;

end

i=(number_nodes-1);

d_wc(i,1)=l(i);
d_wc(i,2)=(-2*wc(i-3,2)+12*wc(i-2,2)-36*wc(i-1,2) ...
 +20*wc(i,2)+6*wc(i+1,2))/denom1;

d2_wc(i,1)=l(i);
d2_wc(i,2)=(-1*wc(i-3,2)+4*wc(i-2,2)+6*wc(i-1,2) ...
 -20*wc(i,2)+11*wc(i+1,2))/denom2;

i=number_nodes;

d_wc(i,1)=l(i);
d_wc(i,2)=(6*wc(i-4,2)-32*wc(i-3,2)+72*wc(i-2,2) ...
 -96*wc(i-1,2)+50*wc(i,2))/denom1;

d2_wc(i,1)=l(i);
d2_wc(i,2)=(11*wc(i-4,2)-56*wc(i-3,2)+114*wc(i-2,2)...
 -104*wc(i-1,2)+35*wc(i,2))/denom2;

% We're done calculating derivatives.  Next calculate v(l), d_v(l).  
% We'll first assume that there is no along-path gradient in water vapor 
% transport velocity at beginning of the path (or, in other words, dw/dl=0).
% Integration will be accomplished in a series of short along-path hops.

i      = 1;
v_i(i) = (E(i,2)-P(i,2))/d_wc(i,2);

for i=1:1:(number_nodes-1)

  l_start=l(i);
  l_stop =l(i+1);

  % First get average values of variables at location:

%  wc_avg   = (wc(i,2)+wc(i+1,2))/2;
%  d_wc_avg = (d_wc(i,2)+d_wc(i+1,2))/2;
%  P_avg    = (P(i,2)+P(i+1,2))/2;
%  E_avg    = (E(i,2)+E(i+1,2))/2;
  wc_avg   = wc(i,2);
  d_wc_avg = d_wc(i,2);
  P_avg    = P(i,2);
  E_avg    = E(i,2);

  % Integrator inputs:

  tspan=[l_start l_stop];

  IC1=1/wc_avg;
  IC2=E_avg-P_avg;
  IC3=d_wc_avg;

  d_v_i(i) = IC1*(IC2-v_i(i)*IC3);

  y_v=[v_i(i)];

  % Integration:

  [T_V,Y_V] = ode45('derivs_v',tspan,y_v,'',IC1,IC2,IC3);

  % Initialize values for next along-path hop:

  last=size(Y_V,1);

  v_i(i+1)   = Y_V(last,1);
  d_v_i(i+1) = IC1*(IC2-v_i(i+1)*IC3);
end

% End of integration for v(l), d_v(l).  Assign to 2-D arrays:

for i=1:1:number_nodes
  v(i,1)   = l(i);
  v(i,2)   = v_i(i);
  d_v(i,1) = l(i);
  d_v(i,2) = d_v_i(i);
end

figure

subplot(2,1,1)
plot(v(:,1),v(:,2),'r-');
xlabel('Along-path length, m')
ylabel('v')

subplot(2,1,2)
plot(d_v(:,1),d_v(:,2),'r-');
xlabel('Along-path length, m')
ylabel('dv/dl')
