function value = alpha_18_iv(T)

% ALPHA_18_IV calculates the ice-vapor equlibrium fractionation factor
% for oxygen-18 at a given temperature T (expressed in Kelvin).

% Equilibrium fractionation factor:

C1=11.839;
C2=0.0282241;

alpha_e = exp(C1/T-C2);

%value=alpha_e;

% Kinetic fractionation:

% Values for tunable parameters C and F are suggested to lie between 
% 1.00 < C < 1.04 and
% 0.005 < F < 0.007 per C, with
% D18 = 1.0285 (see Johnson and others, 1989 for details).

C = 1.04;
F = 0.003;
D18 = 1.0285;

S_i = C-F*(T-273.16);

value = S_i/(1/alpha_e+(S_i-1)*D18);

