function value = alpha_D_eff(T)

% ALPHA_D_EFF calculates the effective equlibrium fractionation 
% factor (i.e. including the ice-vapor and liquid-vapor fractions) 
% for deuterium at a given cloud temperature T (expressed in Kelvin).

T_C  = T-273.16;
T_lo = -15.0;
T_hi = -5.0;
%F_lo = 1.06;  % i.e. value at low temperatures
%F_hi = 1.02;  % i.e. value at high temperatures
F_lo = 1.00;  % i.e. value at low temperatures
F_hi = 1.00;  % i.e. value at high temperatures

if T_C <= T_lo
  factor = F_lo;
elseif T_C >= T_hi
  factor = F_hi;
else
  factor = F_lo - (F_lo-F_hi)*(T_C-T_lo)/(T_hi-T_lo);
end

factor = 1.0;

value1 = fraction_il(T)*alpha_D_iv(T) + (1-fraction_il(T))*alpha_D_lv(T);
value2 = value1-1.0;
value  = 1.0+factor*value2;
