function value = alpha_D_lv(T)

% ALPHA_D_LV calculates liquid-vapor equlibrium fractionation factor.
% ALPHA_D_LV(T), where T is the temperature in Kelvin.

c1= 1158.8e-12;
c2=-1620.1e-9;
c3= 794.84e-6;
c4=-161.04e-3;
c5= 2.9992e6;

T_C=T-273.16;
T_lo = -20.0;
T_hi = -5.0;
F_lo = 1.00;  % i.e. value at low temperatures
F_hi = 1.00;  % i.e. value at high temperatures

if T_C <= T_lo
  factor = F_lo;
elseif T_C >= T_hi
  factor = F_hi;
else
  factor = F_lo - (F_lo-F_hi)*(T_C-T_lo)/(T_hi-T_lo);
end

value1 = exp(c1*T^3+c2*T^2+c3*T+c4+c5/T^3);
value2 = value1 - 1.0;
value  = 1.0+factor*value2;

% Majoube:

%value=exp(24844/T^2-76.248/T+0.052612);

