% make_Andes_path2

% Input files are   (1)  Andes_path1_climate_base.dat: output from 
%                        make_Andes_path1.m (same output format as below)
%                   (2)  Andes_path1_base_del18.dat: output from
%                        iso_Andes1.m (l; del_18a; del_18p; del_18s)
%                   (3)  Andes_path1_base_delD.dat: output from
%                        iso_Andes1.m (l; del_Da; del_Dp; del_Ds)
%                   (4)  Andes_path2_rough.dat: distance, elevation, ppt info

% Output fields are (1)  Distance Along Path (m)
%                   (2)  Surface Temperature (k)
%                   (3)  Cloud Temperature (k)
%                   (4)  Water Content (m)
%                   (5)  Evaporation, (m/s)
%                   (6)  Precipitation, (m/s)
%                   (7)  Flow-Parallel Fraction, 0-1
%                   (8)  Relative Humidity
%                   (9)  Surface Runoff (m/s)
%                   (10) Ocean (1=ocean; 0=land)
%                   (11) Surface water isotopic Content

load Andes_path1_climate_base.dat;
load Andes_path1_base_del18.dat;
load Andes_path1_base_delD.dat;
load Andes_path2_rough.dat;
load Andes_path2_precip.dat;

climate_path1 = Andes_path1_climate_base;
del18_path1   = Andes_path1_base_del18;
delD_path1    = Andes_path1_base_delD;
mapdat_path2  = Andes_path2_rough;
number_mapdat = size(mapdat_path2,1);
precip_path2  = Andes_path2_precip;
number_precip = size(precip_path2,1);

% Path 2 branches off of the Amazonian path (i.e., Path 1) at the 
% along-path distance l_branch_km:

l_branch_km = 4635.0;             % km along path
l_branch    = l_branch_km*1000.0; % m along path

% Data from Path 1 at the branching point will be used.  

l_incr1        = climate_path1(2,1)-climate_path1(1,1);
l_branch       = (floor(l_branch/l_incr1))*l_incr1;
i_l_branch     = l_branch/l_incr1 + 1;

% Write values to a file for use by plot_results.m:

save Andes_path2_branchpoint.dat /ascii l_branch;

% Take initial del_18_a,p,e and del_D_a,p,e values from output files:

start_climate  = climate_path1(i_l_branch,:);
start_del18    = del18_path1(i_l_branch,:);
start_delD     = delD_path1(i_l_branch,:);

initial_del(1,:) = start_del18(1,2:4)/1000.0;
initial_del(2,:) = start_delD(1,2:4)/1000.0;

% Write values to a file for use by iso_Andes2.m:

save Andes_path2_base_initial_del.dat /ascii initial_del;

% Take initial ts, wc, E, P, Rh values from path 1 climate file:

start_ts   = start_climate(2);
start_tc   = start_climate(3);
start_wc   = start_climate(4);
start_E    = start_climate(5);
start_P    = start_climate(6);
start_h    = start_climate(8);

for i=1:1:number_precip
  precip(i,1)        = precip_path2(i,1)*1000;
  precip(i,2)        = start_P*precip_path2(i,2);
end

for i=1:1:number_mapdat
  l_mapdat(i)        = mapdat_path2(i,1)*1000.0; % km to m
%  elev_mapdat(i)     = mapdat_path2(i,2);
%  elev_mapdat(i)     = mapdat_path2(i,3);
  elev_mapdat(i)     = (mapdat_path2(i,2)+mapdat_path2(i,3))/2;
  isohyeta_mapdat(i) = mapdat_path2(i,4);
end

% Interpolate precip data onto mapdat 'grid':

col1_p = precip(:,1)';
col2_p = precip(:,2)';

precip_mapdat(:,1)  = l_mapdat';
precip_mapdat(:,2)  = (interp1(col1_p,col2_p,l_mapdat,'linear'))';

start_l         = l_mapdat(1);
stop_l          = l_mapdat(number_mapdat);
start_elev      = elev_mapdat(1);
stop_elev       = elev_mapdat(number_mapdat);
start_isohyeta  = isohyeta_mapdat(1);

l_center   = 200*1000;   % center of switch: l=200 km
dl         = 100*1000/2; % width of switch: dl=100 km
F_P_start  = 0.0;
F_P_stop   = 1.0;
d_F_P      = F_P_start-F_P_stop;

P_factor_m = 1.0;
P_factor_n = 1.0;
P_m        = start_P;
P_n0       = P_factor_n*P_m;

for i=1:1:number_mapdat
  P_n(i)   = precip_mapdat(i,2);
  F_P(i)   = F_P_start-(d_F_P/2)*(1+erf((precip_mapdat(i,1)-l_center)/dl));
end

La_Paz_elev     = 3625.0; % masl
%La_Paz_ts       = 9.9 + 273.16; % Mean Jan temp at La Paz, K
La_Paz_ts       = 9.9 + 273.16; % Mean Jan temp at La Paz, K

m_ts            = (La_Paz_ts-start_ts)/(La_Paz_elev-start_elev);
b_ts            = start_ts - m_ts*start_elev;

for i=1:1:number_mapdat
  l_path2(i)   = l_mapdat(i);
  ts_path2(i)  = m_ts*elev_mapdat(i)+b_ts;
  wc_path2(i)  = start_wc*(sat_vapor(ts_path2(i))/sat_vapor(start_ts));
  E_path2(i)   = start_E*(sat_vapor(ts_path2(i))/sat_vapor(start_ts));
  P_path2(i)   = (1-F_P(i))*P_m + F_P(i)*P_n(i);
  h_path2(i)   = start_h;
  run_path2(i) = P_path2(i)-E_path2(i);
  if run_path2(i) < 0.0;
    run_path2(i)    = 0.0;
  end
  ocean_path2(i)    = 0;
  wateriso_path2(i) = 0.0;
end

summit_flag = 0;
for i=2:1:number_mapdat
  if ts_path2(i)>ts_path2(i-1)
    if summit_flag==0
      summit_flag = 1;
      i_summit    = i;
      summit_ts   = ts_path2(i-1);
      summit_wc   = wc_path2(i-1);
      wc_path2(i) = summit_wc*(sat_vapor(summit_ts)/sat_vapor(ts_path2(i)));
    else
      wc_path2(i) = summit_wc*(sat_vapor(summit_ts)/sat_vapor(ts_path2(i)));
    end
  end 
end

climate(:,1)  = l_path2';
climate(:,2)  = ts_path2';
climate(:,3)  = wc_path2';
climate(:,4)  = E_path2';
climate(:,5)  = P_path2';
climate(:,6)  = h_path2';
climate(:,7)  = run_path2';
climate(:,8)  = ocean_path2';
climate(:,9)  = wateriso_path2';
climate(:,10) = elev_mapdat';

% Ensure that the the specified path length works out to an integer 
% number of nodes, and that the branch point falls on a node.  First, 
% we'll shrink the pathlength a bit to be an integer number of nodes:

l_incr  = 1.0*1000.0; % 1 km resolution;

i_start_l = 1;
start_l   = climate(i_start_l,1);
i_stop_l  = number_mapdat;
stop_l    = climate(i_stop_l,1);

shrinkfactor = ((floor((stop_l-start_l)/l_incr))*l_incr)/(stop_l-start_l);

for i=1:1:number_mapdat
  climate(i,1)=shrinkfactor*(climate(i,1)-start_l);
end

% New pathlength:

stop_l = climate(i_stop_l,1);

% Next, we'll project the data onto a regularly-spaced grid:

number_total = (stop_l-start_l)/l_incr+1;

for i=1:1:number_total
  l(i) = start_l+(i-1)*l_incr;
end

col1  = climate(:,1);
col2  = climate(:,2);
col3  = climate(:,3);
col4  = climate(:,4);
col5  = climate(:,5);
col6  = climate(:,6);
col7  = climate(:,7);
col8  = climate(:,8);
col9  = climate(:,9);
col10 = climate(:,10);

climate_regular(:,1)  = l';
climate_regular(:,2)  = (interp1(col1,col2,l,'linear'))';
climate_regular(:,3)  = (interp1(col1,col3,l,'linear'))';
climate_regular(:,4)  = (interp1(col1,col4,l,'linear'))';
climate_regular(:,5)  = (interp1(col1,col5,l,'linear'))';
climate_regular(:,6)  = (interp1(col1,col6,l,'linear'))';
climate_regular(:,7)  = (interp1(col1,col7,l,'linear'))';
climate_regular(:,8)  = (interp1(col1,col8,l,'linear'))';
climate_regular(:,9)  = (interp1(col1,col9,l,'linear'))';
climate_regular(:,10) = (interp1(col1,col10,l,'linear'))';

number_nodes  = size(climate_regular,1);

% Now we can start working with the data.  First, convert to useful units:

% Surface temp: already in K; no change.
ts_raw(:,1)     = climate_regular(:,1);
ts_raw(:,2)     = climate_regular(:,2);

% Water content: no change:
wc_raw(:,1)     = climate_regular(:,1);
wc_raw(:,2)     = climate_regular(:,3);

% Evaporation: no change:
E_raw(:,1)      = climate_regular(:,1);
E_raw(:,2)      = climate_regular(:,4);

% Precipitation: no change:
P_raw(:,1)      = climate_regular(:,1);
P_raw(:,2)      = climate_regular(:,5);

% Relative humidity: no change:
h_raw(:,1)      = climate_regular(:,1);
h_raw(:,2)      = climate_regular(:,6);

% Runoff: no change:
run_raw(:,1)    = climate_regular(:,1);
run_raw(:,2)    = climate_regular(:,7);

% Ocean index: no change:
ocean(:,1)      = climate_regular(:,1);
ocean(:,2)      = climate_regular(:,8);

% Surface water del 18 O: no change:
del_18_w(:,1)   = climate_regular(:,1);
del_18_w(:,2)   = climate_regular(:,9);

% Surface elevation: no change:
elev_raw(:,1)   = climate_regular(:,1);
elev_raw(:,2)   = climate_regular(:,10);

% Calculate the flow-parallel component of the mean water vapor flux:

l_center = 200.0*1000; % center of switch: l=200 km
dl       = 100*1000/2; % width of switch: dl=100 km
F_start  = 0.05;
F_stop   = 1.0;
d_F      = F_start-F_stop;

for i=1:1:number_nodes
  F(i,1) = l(i);
  F(i,2) = F_start-(d_F/2)*(1+erf((F(i,1)-l_center)/dl));
end

% Now smooth the data.  First smooth ts_raw.  The function 'filter', is, 
% sadly, assymetric.  We'll thus apply it twice (once in each direction) 
% for each filtered variable and average the results.  Backwards first:

x_f(1)=ts_raw(1,2)-11*(ts_raw(2,2)-ts_raw(1,2));
x_f(2)=ts_raw(1,2)-10*(ts_raw(2,2)-ts_raw(1,2));
x_f(3)=ts_raw(1,2)-9*(ts_raw(2,2)-ts_raw(1,2));
x_f(4)=ts_raw(1,2)-8*(ts_raw(2,2)-ts_raw(1,2));
x_f(5)=ts_raw(1,2)-7*(ts_raw(2,2)-ts_raw(1,2));
x_f(6)=ts_raw(1,2)-6*(ts_raw(2,2)-ts_raw(1,2));
x_f(7)=ts_raw(1,2)-5*(ts_raw(2,2)-ts_raw(1,2));
x_f(8)=ts_raw(1,2)-4*(ts_raw(2,2)-ts_raw(1,2));
x_f(9)=ts_raw(1,2)-3*(ts_raw(2,2)-ts_raw(1,2));
x_f(10)=ts_raw(1,2)-2*(ts_raw(2,2)-ts_raw(1,2));
x_f(11)=ts_raw(1,2)-1*(ts_raw(2,2)-ts_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=ts_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

ts_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  ts_1(i,1)=l(i);
  ts_1(i,2)=ts_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  ts_raw_rev(i,1)=ts_raw((number_nodes-i)+1,1);
  ts_raw_rev(i,2)=ts_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=ts_raw_rev(1,2)-11*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(2)=ts_raw_rev(1,2)-10*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(3)=ts_raw_rev(1,2)-9*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(4)=ts_raw_rev(1,2)-8*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(5)=ts_raw_rev(1,2)-7*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(6)=ts_raw_rev(1,2)-6*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(7)=ts_raw_rev(1,2)-5*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(8)=ts_raw_rev(1,2)-4*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(9)=ts_raw_rev(1,2)-3*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(10)=ts_raw_rev(1,2)-2*(ts_raw_rev(2,2)-ts_raw_rev(1,2));
x_f(11)=ts_raw_rev(1,2)-1*(ts_raw_rev(2,2)-ts_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=ts_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

ts_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  ts_2_rev(i,1)=l((number_nodes-i)+1);
  ts_2_rev(i,2)=ts_filt_2(i+11);
end

for i=1:1:number_nodes
  ts_2(i,1)=l(i);
  ts_2(i,2)=ts_2_rev((number_nodes-i)+1,2);
  ts(i,1)=l(i);
  ts(i,2)=(ts_1(i,2)+ts_2(i,2))/2;
end

% Done smoothing ts.  Next, calculate cloud temperature tc field.  
% Since it is derived from the smoothed surface temperature field, 
% no smoothing is needed:

% Calculate the effective condensation (or "cloud") temperature:
% We'll blend the constant tc of the Amazonian path with a lapse-rate 
% formulation for the Andean portion:

l_center    = 200.0*1000; % center of switch: l=200 km
dl          = 100.0*1000/2; % width of switch: dl=100 km
F_tc_start  = 0.0;
F_tc_stop   = 1.0;
d_F_tc      = F_tc_start-F_tc_stop;

for i=1:1:number_nodes
  F_tc(i)   = F_tc_start-(d_F_tc/2)*(1+erf((F(i,1)-l_center)/dl));
%  tc_1(i)   = 273.16;
  tc_1(i)   = start_tc;
  tc_2(i)   = temp_cloud(ts(i,2));
  tc(i,1)   = l(i);
  tc(i,2)   = (1-F_tc(i))*tc_1(i) + F_tc(i)*tc_2(i);
end

% Smooth wc_raw.  Backwards first:

x_f(1)=wc_raw(1,2)-11*(wc_raw(2,2)-wc_raw(1,2));
x_f(2)=wc_raw(1,2)-10*(wc_raw(2,2)-wc_raw(1,2));
x_f(3)=wc_raw(1,2)-9*(wc_raw(2,2)-wc_raw(1,2));
x_f(4)=wc_raw(1,2)-8*(wc_raw(2,2)-wc_raw(1,2));
x_f(5)=wc_raw(1,2)-7*(wc_raw(2,2)-wc_raw(1,2));
x_f(6)=wc_raw(1,2)-6*(wc_raw(2,2)-wc_raw(1,2));
x_f(7)=wc_raw(1,2)-5*(wc_raw(2,2)-wc_raw(1,2));
x_f(8)=wc_raw(1,2)-4*(wc_raw(2,2)-wc_raw(1,2));
x_f(9)=wc_raw(1,2)-3*(wc_raw(2,2)-wc_raw(1,2));
x_f(10)=wc_raw(1,2)-2*(wc_raw(2,2)-wc_raw(1,2));
x_f(11)=wc_raw(1,2)-1*(wc_raw(2,2)-wc_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=wc_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

wc_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  wc_1(i,1)=l(i);
  wc_1(i,2)=wc_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  wc_raw_rev(i,1)=wc_raw((number_nodes-i)+1,1);
  wc_raw_rev(i,2)=wc_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=wc_raw_rev(1,2)-11*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(2)=wc_raw_rev(1,2)-10*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(3)=wc_raw_rev(1,2)-9*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(4)=wc_raw_rev(1,2)-8*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(5)=wc_raw_rev(1,2)-7*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(6)=wc_raw_rev(1,2)-6*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(7)=wc_raw_rev(1,2)-5*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(8)=wc_raw_rev(1,2)-4*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(9)=wc_raw_rev(1,2)-3*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(10)=wc_raw_rev(1,2)-2*(wc_raw_rev(2,2)-wc_raw_rev(1,2));
x_f(11)=wc_raw_rev(1,2)-1*(wc_raw_rev(2,2)-wc_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=wc_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

wc_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  wc_2_rev(i,1)=l((number_nodes-i)+1);
  wc_2_rev(i,2)=wc_filt_2(i+11);
end

for i=1:1:number_nodes
  wc_2(i,1)=l(i);
  wc_2(i,2)=wc_2_rev((number_nodes-i)+1,2);
  wc(i,1)=l(i);
  wc(i,2)=(wc_1(i,2)+wc_2(i,2))/2;
end

% Done smoothing wc.  Next, smooth E_raw.  Backwards first:

x_f(1)=E_raw(1,2)-11*(E_raw(2,2)-E_raw(1,2));
x_f(2)=E_raw(1,2)-10*(E_raw(2,2)-E_raw(1,2));
x_f(3)=E_raw(1,2)-9*(E_raw(2,2)-E_raw(1,2));
x_f(4)=E_raw(1,2)-8*(E_raw(2,2)-E_raw(1,2));
x_f(5)=E_raw(1,2)-7*(E_raw(2,2)-E_raw(1,2));
x_f(6)=E_raw(1,2)-6*(E_raw(2,2)-E_raw(1,2));
x_f(7)=E_raw(1,2)-5*(E_raw(2,2)-E_raw(1,2));
x_f(8)=E_raw(1,2)-4*(E_raw(2,2)-E_raw(1,2));
x_f(9)=E_raw(1,2)-3*(E_raw(2,2)-E_raw(1,2));
x_f(10)=E_raw(1,2)-2*(E_raw(2,2)-E_raw(1,2));
x_f(11)=E_raw(1,2)-1*(E_raw(2,2)-E_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=E_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

E_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  E_1(i,1)=l(i);
  E_1(i,2)=E_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  E_raw_rev(i,1)=E_raw((number_nodes-i)+1,1);
  E_raw_rev(i,2)=E_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=E_raw_rev(1,2)-11*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(2)=E_raw_rev(1,2)-10*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(3)=E_raw_rev(1,2)-9*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(4)=E_raw_rev(1,2)-8*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(5)=E_raw_rev(1,2)-7*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(6)=E_raw_rev(1,2)-6*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(7)=E_raw_rev(1,2)-5*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(8)=E_raw_rev(1,2)-4*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(9)=E_raw_rev(1,2)-3*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(10)=E_raw_rev(1,2)-2*(E_raw_rev(2,2)-E_raw_rev(1,2));
x_f(11)=E_raw_rev(1,2)-1*(E_raw_rev(2,2)-E_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=E_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

E_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  E_2_rev(i,1)=l((number_nodes-i)+1);
  E_2_rev(i,2)=E_filt_2(i+11);
end

for i=1:1:number_nodes
  E_2(i,1)=l(i);
  E_2(i,2)=E_2_rev((number_nodes-i)+1,2);
  E(i,1)=l(i);
  E(i,2)=(E_1(i,2)+E_2(i,2))/2;
%  E(i,2)=0.0;
end

% Done smoothing E.  Smooth P_raw, backwards first:

x_f(1)=P_raw(1,2)-11*(P_raw(2,2)-P_raw(1,2));
x_f(2)=P_raw(1,2)-10*(P_raw(2,2)-P_raw(1,2));
x_f(3)=P_raw(1,2)-9*(P_raw(2,2)-P_raw(1,2));
x_f(4)=P_raw(1,2)-8*(P_raw(2,2)-P_raw(1,2));
x_f(5)=P_raw(1,2)-7*(P_raw(2,2)-P_raw(1,2));
x_f(6)=P_raw(1,2)-6*(P_raw(2,2)-P_raw(1,2));
x_f(7)=P_raw(1,2)-5*(P_raw(2,2)-P_raw(1,2));
x_f(8)=P_raw(1,2)-4*(P_raw(2,2)-P_raw(1,2));
x_f(9)=P_raw(1,2)-3*(P_raw(2,2)-P_raw(1,2));
x_f(10)=P_raw(1,2)-2*(P_raw(2,2)-P_raw(1,2));
x_f(11)=P_raw(1,2)-1*(P_raw(2,2)-P_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=P_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

P_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  P_1(i,1)=l(i);
  P_1(i,2)=P_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  P_raw_rev(i,1)=P_raw((number_nodes-i)+1,1);
  P_raw_rev(i,2)=P_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=P_raw_rev(1,2)-11*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(2)=P_raw_rev(1,2)-10*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(3)=P_raw_rev(1,2)-9*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(4)=P_raw_rev(1,2)-8*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(5)=P_raw_rev(1,2)-7*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(6)=P_raw_rev(1,2)-6*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(7)=P_raw_rev(1,2)-5*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(8)=P_raw_rev(1,2)-4*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(9)=P_raw_rev(1,2)-3*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(10)=P_raw_rev(1,2)-2*(P_raw_rev(2,2)-P_raw_rev(1,2));
x_f(11)=P_raw_rev(1,2)-1*(P_raw_rev(2,2)-P_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=P_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

P_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  P_2_rev(i,1)=l((number_nodes-i)+1);
  P_2_rev(i,2)=P_filt_2(i+11);
end

for i=1:1:number_nodes
  P_2(i,1)=l(i);
  P_2(i,2)=P_2_rev((number_nodes-i)+1,2);
  P(i,1)=l(i);
  P(i,2)=(P_1(i,2)+P_2(i,2))/2;
end

% Done smoothing P.  Smooth h_raw, backwards first:

x_f(1)=h_raw(1,2)-11*(h_raw(2,2)-h_raw(1,2));
x_f(2)=h_raw(1,2)-10*(h_raw(2,2)-h_raw(1,2));
x_f(3)=h_raw(1,2)-9*(h_raw(2,2)-h_raw(1,2));
x_f(4)=h_raw(1,2)-8*(h_raw(2,2)-h_raw(1,2));
x_f(5)=h_raw(1,2)-7*(h_raw(2,2)-h_raw(1,2));
x_f(6)=h_raw(1,2)-6*(h_raw(2,2)-h_raw(1,2));
x_f(7)=h_raw(1,2)-5*(h_raw(2,2)-h_raw(1,2));
x_f(8)=h_raw(1,2)-4*(h_raw(2,2)-h_raw(1,2));
x_f(9)=h_raw(1,2)-3*(h_raw(2,2)-h_raw(1,2));
x_f(10)=h_raw(1,2)-2*(h_raw(2,2)-h_raw(1,2));
x_f(11)=h_raw(1,2)-1*(h_raw(2,2)-h_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=h_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

h_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  h_1(i,1)=l(i);
  h_1(i,2)=h_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  h_raw_rev(i,1)=h_raw((number_nodes-i)+1,1);
  h_raw_rev(i,2)=h_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=h_raw_rev(1,2)-11*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(2)=h_raw_rev(1,2)-10*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(3)=h_raw_rev(1,2)-9*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(4)=h_raw_rev(1,2)-8*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(5)=h_raw_rev(1,2)-7*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(6)=h_raw_rev(1,2)-6*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(7)=h_raw_rev(1,2)-5*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(8)=h_raw_rev(1,2)-4*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(9)=h_raw_rev(1,2)-3*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(10)=h_raw_rev(1,2)-2*(h_raw_rev(2,2)-h_raw_rev(1,2));
x_f(11)=h_raw_rev(1,2)-1*(h_raw_rev(2,2)-h_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=h_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

h_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  h_2_rev(i,1)=l((number_nodes-i)+1);
  h_2_rev(i,2)=h_filt_2(i+11);
end

for i=1:1:number_nodes
  h_2(i,1)=l(i);
  h_2(i,2)=h_2_rev((number_nodes-i)+1,2);
  h(i,1)=l(i);
  h(i,2)=(h_1(i,2)+h_2(i,2))/2;
end

% Done smoothing h.  Next smooth run_raw, backwards first:

x_f(1)=run_raw(1,2)-11*(run_raw(2,2)-run_raw(1,2));
x_f(2)=run_raw(1,2)-10*(run_raw(2,2)-run_raw(1,2));
x_f(3)=run_raw(1,2)-9*(run_raw(2,2)-run_raw(1,2));
x_f(4)=run_raw(1,2)-8*(run_raw(2,2)-run_raw(1,2));
x_f(5)=run_raw(1,2)-7*(run_raw(2,2)-run_raw(1,2));
x_f(6)=run_raw(1,2)-6*(run_raw(2,2)-run_raw(1,2));
x_f(7)=run_raw(1,2)-5*(run_raw(2,2)-run_raw(1,2));
x_f(8)=run_raw(1,2)-4*(run_raw(2,2)-run_raw(1,2));
x_f(9)=run_raw(1,2)-3*(run_raw(2,2)-run_raw(1,2));
x_f(10)=run_raw(1,2)-2*(run_raw(2,2)-run_raw(1,2));
x_f(11)=run_raw(1,2)-1*(run_raw(2,2)-run_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=run_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

run_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  run_1(i,1)=l(i);
  run_1(i,2)=run_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  run_raw_rev(i,1)=run_raw((number_nodes-i)+1,1);
  run_raw_rev(i,2)=run_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=run_raw_rev(1,2)-11*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(2)=run_raw_rev(1,2)-10*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(3)=run_raw_rev(1,2)-9*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(4)=run_raw_rev(1,2)-8*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(5)=run_raw_rev(1,2)-7*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(6)=run_raw_rev(1,2)-6*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(7)=run_raw_rev(1,2)-5*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(8)=run_raw_rev(1,2)-4*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(9)=run_raw_rev(1,2)-3*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(10)=run_raw_rev(1,2)-2*(run_raw_rev(2,2)-run_raw_rev(1,2));
x_f(11)=run_raw_rev(1,2)-1*(run_raw_rev(2,2)-run_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=run_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

run_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  run_2_rev(i,1)=l((number_nodes-i)+1);
  run_2_rev(i,2)=run_filt_2(i+11);
end

for i=1:1:number_nodes
  run_2(i,1)=l(i);
  run_2(i,2)=run_2_rev((number_nodes-i)+1,2);
  run(i,1)=l(i);
  run(i,2)=(run_1(i,2)+run_2(i,2))/2;
end

% Done smoothing run.  Next smooth elev_raw, backwards first:

x_f(1)=elev_raw(1,2)-11*(elev_raw(2,2)-elev_raw(1,2));
x_f(2)=elev_raw(1,2)-10*(elev_raw(2,2)-elev_raw(1,2));
x_f(3)=elev_raw(1,2)-9*(elev_raw(2,2)-elev_raw(1,2));
x_f(4)=elev_raw(1,2)-8*(elev_raw(2,2)-elev_raw(1,2));
x_f(5)=elev_raw(1,2)-7*(elev_raw(2,2)-elev_raw(1,2));
x_f(6)=elev_raw(1,2)-6*(elev_raw(2,2)-elev_raw(1,2));
x_f(7)=elev_raw(1,2)-5*(elev_raw(2,2)-elev_raw(1,2));
x_f(8)=elev_raw(1,2)-4*(elev_raw(2,2)-elev_raw(1,2));
x_f(9)=elev_raw(1,2)-3*(elev_raw(2,2)-elev_raw(1,2));
x_f(10)=elev_raw(1,2)-2*(elev_raw(2,2)-elev_raw(1,2));
x_f(11)=elev_raw(1,2)-1*(elev_raw(2,2)-elev_raw(1,2));

for i=1:1:number_nodes
  x_f(i+11)=elev_raw(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

elev_filt_1=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  elev_1(i,1)=l(i);
  elev_1(i,2)=elev_filt_1(i+11);
  % The two following lines create a reversed record so we 
  % can filter in the forward direction:
  elev_raw_rev(i,1)=elev_raw((number_nodes-i)+1,1);
  elev_raw_rev(i,2)=elev_raw((number_nodes-i)+1,2);
end

% Now forwards:

x_f(1)=elev_raw_rev(1,2)-11*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(2)=elev_raw_rev(1,2)-10*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(3)=elev_raw_rev(1,2)-9*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(4)=elev_raw_rev(1,2)-8*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(5)=elev_raw_rev(1,2)-7*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(6)=elev_raw_rev(1,2)-6*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(7)=elev_raw_rev(1,2)-5*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(8)=elev_raw_rev(1,2)-4*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(9)=elev_raw_rev(1,2)-3*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(10)=elev_raw_rev(1,2)-2*(elev_raw_rev(2,2)-elev_raw_rev(1,2));
x_f(11)=elev_raw_rev(1,2)-1*(elev_raw_rev(2,2)-elev_raw_rev(1,2));

for i=1:1:number_nodes
  x_f(i+11)=elev_raw_rev(i,2);
end

a_f=1;
b_f=[1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12 1/12];

elev_filt_2=filter(b_f,a_f,x_f);

for i=1:1:number_nodes
  elev_2_rev(i,1)=l((number_nodes-i)+1);
  elev_2_rev(i,2)=elev_filt_2(i+11);
end

for i=1:1:number_nodes
  elev_2(i,1)=l(i);
  elev_2(i,2)=elev_2_rev((number_nodes-i)+1,2);
  elev(i,1)=l(i);
  elev(i,2)=(elev_1(i,2)+elev_2(i,2))/2;
end

% Done smoothing elev.  
% Now that all fields have been generated and 
% smoothed, write 'em out:

out(:,1)  = l';
out(:,2)  = ts(:,2);
out(:,3)  = tc(:,2);
out(:,4)  = wc(:,2);
out(:,5)  = E(:,2);
out(:,6)  = P(:,2);
out(:,7)  = F(:,2);
out(:,8)  = h(:,2);
out(:,9)  = elev(:,2);
out(:,10) = ocean(:,2);
out(:,11) = del_18_w(:,2);

save Andes_path2_climate_base.dat /ascii out;
save Andes_path2_elev.dat /ascii elev;

% Plot data fields:

m_s_to_m_a = 365.25*24*60*60;

figure
subplot(3,2,1)
plot(ts(:,1)/1000,ts(:,2)-273.16,'b-')
hold
plot(tc(:,1)/1000,tc(:,2)-273.16,'r-')
title('Andean Parameter Fields, January')
xlabel('L, km')
ylabel('T_s (b); T_c (r), C')
grid

subplot(3,2,2)
plot(wc(:,1)/1000,wc(:,2)*1000,'b-')
xlabel('L, km')
ylabel('wc, mm')
grid

subplot(3,2,3)
plot(P(:,1)/1000,P(:,2)*m_s_to_m_a,'b-')
xlabel('L, km')
ylabel('P, m/a')
grid

subplot(3,2,4)
plot(E(:,1)/1000,E(:,2)*m_s_to_m_a,'r-')
xlabel('L, km')
ylabel('E, m/a')
grid

subplot(3,2,5)
plot(h(:,1)/1000,h(:,2)*100,'r-')
xlabel('L, km')
ylabel('R_h, %')
grid

subplot(3,2,6)
plot(run(:,1)/1000,(P(:,2)-E(:,2))*m_s_to_m_a,'b-')
xlabel('L, km')
ylabel('Runoff, m/a')
grid

print -dpsc Andes_path2_fields_jan.ps

